@@ -20,13 +20,13 @@ def iir_notch(notch_freq, fs, Q=30):
     return b, a
 
 
-def applyButter(sample, whichFilters, highPass, lowPass, notchFilter):
+def applyButter(sample, highPass, lowPass, notchFilter):
     filtered = sample
-    if whichFilters[0] == 1:  # Low pass
+    if lowPass is not None:  # Low pass
         filtered = lfilter(lowPass[0], lowPass[1], filtered)
-    if whichFilters[1] == 1:
+    if highPass is not None:
         filtered = lfilter(notchFilter[0], notchFilter[1], filtered)
-    if whichFilters[2] == 1:
+    if notchFilter is not None:
         filtered = lfilter(highPass[0], highPass[1], filtered)
 
-    return sample
+    return filtered
